@@ -8,7 +8,7 @@ use super::Microdesc;
 use crate::types::family::RelayFamily;
 use crate::types::policy::PortPolicy;
 use crate::{Error, Result};
-use tor_llcrypto::pk::{curve25519, ed25519, rsa};
+use tor_llcrypto::pk::{curve25519, ed25519};
 
 use rand::Rng;
 
@@ -20,10 +20,6 @@ use rand::Rng;
 /// the `build_docs` feature.
 #[derive(Debug, Clone)]
 pub struct MicrodescBuilder {
-    /// The TAP onion key we'll be using.
-    ///
-    /// See [`Microdesc::tap_onion_key`].
-    tap_onion_key: Option<rsa::PublicKey>,
     /// The ntor onion key we'll be using.
     ///
     /// See [`Microdesc::ntor_onion_key`].
@@ -44,7 +40,6 @@ impl MicrodescBuilder {
     /// Create a new MicrodescBuilder.
     pub(crate) fn new() -> Self {
         MicrodescBuilder {
-            tap_onion_key: None,
             ntor_onion_key: None,
             family: RelayFamily::new(),
             ipv4_policy: PortPolicy::new_reject_all(),
@@ -53,14 +48,6 @@ impl MicrodescBuilder {
         }
     }
 
-    /// Set the TAP onion key.
-    ///
-    /// This key is required for a well-formed microdescriptor.
-    pub fn tap_key(&mut self, key: rsa::PublicKey) -> &mut Self {
-        self.tap_onion_key = Some(key);
-        self
-    }
-
     /// Set the ntor onion key.
     ///
     /// This key is required for a well-formed microdescriptor.
@@ -135,11 +122,6 @@ impl MicrodescBuilder {
     /// In the future, when we have authority support, we'll need an
     /// encoder function instead.
     pub fn testing_md(&self) -> Result<Microdesc> {
-        let tap_onion_key = self
-            .tap_onion_key
-            .as_ref()
-            .ok_or(Error::CannotBuild("Missing tap_key"))?
-            .clone();
         let ntor_onion_key = self
             .ntor_onion_key
             .ok_or(Error::CannotBuild("Missing ntor_key"))?;
@@ -153,7 +135,6 @@ impl MicrodescBuilder {
 
         Ok(Microdesc {
             sha256,
-            tap_onion_key,
             ntor_onion_key,
             family: self.family.clone(),
             ipv4_policy: self.ipv4_policy.clone().intern(),
@@ -167,21 +148,13 @@ impl MicrodescBuilder {
 mod test {
     #![allow(clippy::unwrap_used)]
     use super::*;
-    use hex_literal::hex;
-
-    fn rsa_example() -> rsa::PublicKey {
-        let der = hex!("30818902818100d527b6c63d6e81d39c328a94ce157dccdc044eb1ad8c210c9c9e22487b4cfade6d4041bd10469a657e3d82bc00cf62ac3b6a99247e573b54c10c47f5dc849b0accda031eca6f6e5dc85677f76dec49ff24d2fcb2b5887fb125aa204744119bb6417f45ee696f8dfc1c2fc21b2bae8e9e37a19dc2518a2c24e7d8fd7fac0f46950203010001");
-        rsa::PublicKey::from_der(&der).unwrap()
-    }
 
     #[test]
     fn minimal() {
-        let rsa = rsa_example();
         let ed: ed25519::Ed25519Identity = (*b"this is not much of a public key").into();
         let ntor: curve25519::PublicKey = (*b"but fortunately nothing cares...").into();
 
         let md = MicrodescBuilder::new()
-            .tap_key(rsa.clone())
             .ed25519_id(ed)
             .ntor_key(ntor)
             .testing_md()
@@ -189,19 +162,16 @@ mod test {
 
         assert_eq!(md.ed25519_id(), &ed);
         assert_eq!(md.ntor_key(), &ntor);
-        assert_eq!(md.tap_onion_key.to_rsa_identity(), rsa.to_rsa_identity());
 
         assert_eq!(md.family().members().count(), 0);
     }
 
     #[test]
     fn maximal() -> Result<()> {
-        let rsa = rsa_example();
         let ed: ed25519::Ed25519Identity = (*b"this is not much of a public key").into();
         let ntor: curve25519::PublicKey = (*b"but fortunately nothing cares...").into();
 
         let md = Microdesc::builder()
-            .tap_key(rsa)
             .ed25519_id(ed)
             .ntor_key(ntor)
             .parse_ipv4_policy("accept 80,443")?
@@ -226,25 +196,18 @@ mod test {
 
     #[test]
     fn failing() {
-        let rsa = rsa_example();
         let ed: ed25519::Ed25519Identity = (*b"this is not much of a public key").into();
         let ntor: curve25519::PublicKey = (*b"but fortunately nothing cares...").into();
 
         {
             let mut builder = Microdesc::builder();
-            builder.tap_key(rsa.clone()).ed25519_id(ed);
+            builder.ed25519_id(ed);
             assert!(builder.testing_md().is_err()); // no ntor
         }
 
         {
             let mut builder = Microdesc::builder();
-            builder.ntor_key(ntor).ed25519_id(ed);
-            assert!(builder.testing_md().is_err()); // no tap
-        }
-
-        {
-            let mut builder = Microdesc::builder();
-            builder.tap_key(rsa).ntor_key(ntor);
+            builder.ntor_key(ntor);
             assert!(builder.testing_md().is_err()); // no ed id.
         }
     }
