@@ -367,7 +367,7 @@ bitflags! {
         /// Clients choose their their initial relays from among the set
         /// of Guard relays.
         const GUARD = (1<<4);
-        /// Does this relay participate on the hidden service directory
+        /// Does this relay participate on the onion service directory
         /// ring?
         const HSDIR = (1<<5);
         /// If set, there is no consensus for the ed25519 key for this relay.
@@ -442,7 +442,7 @@ struct Footer {
 
 /// Trait to parse a single relay as listed in a consensus document.
 ///
-/// XXXX: I'd rather not have this trait be public, but I haven't yet
+/// TODO(nickm): I'd rather not have this trait be public, but I haven't yet
 /// figured out how to make it private.
 pub trait ParseRouterStatus: Sized + Sealed {
     /// Parse this object from a `Section` object containing its
@@ -1386,6 +1386,7 @@ impl<RS> UnvalidatedConsensus<RS> {
     /// Tell the unvalidated consensus how many authorities we believe in.
     ///
     /// Without knowing this number, we can't validate the signature.
+    #[must_use]
     pub fn set_n_authorities(self, n_authorities: u16) -> Self {
         UnvalidatedConsensus {
             n_authorities: Some(n_authorities),
