@@ -322,7 +322,10 @@ pub type UncheckedRouterDesc = signed::SignatureGated<timed::TimerangeBound<Rout
 const ROUTER_EXPIRY_SECONDS: u64 = 5 * 86400;
 
 /// How long before its published time is a router descriptor usable?
-// XXXX use the correct value.  Is it specified?
+// TODO(nickm): This valid doesn't match C tor, which only enforces this rule
+// ("routers should not some from the future") at directory authorities, and
+// there only enforces a 12-hour limit (`ROUTER_ALLOW_SKEW`).  Eventually we
+// should probably harmonize these cutoffs.
 const ROUTER_PRE_VALIDITY_SECONDS: u64 = 86400;
 
 impl RouterDesc {
@@ -445,8 +448,6 @@ impl RouterDesc {
         // Extract ed25519 signature.
         let ed_signature: ll::pk::ed25519::ValidatableEd25519Signature = {
             let mut d = ll::d::Sha256::new();
-            // XXXX spec is ambiguous whether this prefix goes on
-            // before or after taking the hash.
             d.update(&b"Tor router descriptor signature v1"[..]);
             let signed_end = ed_sig_pos + b"router-sig-ed25519 ".len();
             d.update(&s[start_offset..signed_end]);
@@ -507,7 +508,7 @@ impl RouterDesc {
             }
             let ntor_as_ed =
                 ll::pk::keymanip::convert_curve25519_to_ed25519_public(&ntor_onion_key, sign)
-                    .ok_or_else(|| Error::Internal(cc.pos()))?; // XXX not really 'internal'
+                    .ok_or_else(|| Error::BadArgument(cc.pos(), "Uncheckable crosscert".into()))?;
 
             cc.parse_obj::<UnvalidatedEdCert>("ED25519 CERT")?
                 .check_cert_type(tor_cert::CertType::NTOR_CC_IDENTITY)?
