@@ -116,6 +116,7 @@ impl Pos {
     ///
     /// TODO: I wish I knew an efficient safe way to do this that
     /// guaranteed that we we always talking about the right string.
+    #[must_use]
     pub fn within(self, s: &str) -> Self {
         match self {
             Pos::Byte { off } => Self::from_offset(s, off),
@@ -232,13 +233,13 @@ pub enum Error {
     MissingArgument(Pos),
     /// We found an argument that couldn't be parsed.
     #[error("bad argument for entry{0}: {1}")]
-    BadArgument(Pos, String), // converting to a string doesn't sit well with me. XXXX
+    BadArgument(Pos, String),
     /// We found an object that couldn't be parsed after it was decoded.
     #[error("bad object for entry{0}: {1}")]
-    BadObjectVal(Pos, String), // converting to a string doesn't sit well with me. XXXX
+    BadObjectVal(Pos, String),
     /// There was some signature that we couldn't validate.
     #[error("couldn't validate signature{0}")]
-    BadSignature(Pos), // say which kind of signature. TODO
+    BadSignature(Pos), // TODO(nickm): say which kind of signature.
     /// There was a tor version we couldn't parse.
     #[error("couldn't parse Tor version{0}")]
     BadTorVersion(Pos),
@@ -316,8 +317,8 @@ impl Error {
 
     /// Helper: return this error's position.
     pub(crate) fn pos(&self) -> Pos {
-        // XXXX This duplicate code is yucky. We should refactor this error
-        // type to use an ErrorKind pattern.
+        // TODO(nickm): This duplicate code is yucky. We should
+        // refactor this error type to use an ErrorKind pattern.
         use Error::*;
         let pos = match self {
             Internal(p) => Some(p),
@@ -358,6 +359,7 @@ impl Error {
 
     /// Return a new error based on this one, with any byte-based
     /// position mapped to some line within a string.
+    #[must_use]
     pub fn within(mut self, s: &str) -> Error {
         if let Some(p) = self.pos_mut() {
             *p = p.within(s);
@@ -367,6 +369,7 @@ impl Error {
 
     /// Return a new error based on this one, with the position (if
     /// any) replaced by 'p'.
+    #[must_use]
     pub fn at_pos(mut self, p: Pos) -> Error {
         if let Some(mypos) = self.pos_mut() {
             *mypos = p;
@@ -376,6 +379,7 @@ impl Error {
 
     /// Return a new error based on this one, with the position (if
     /// replaced by 'p' if it had no position before.
+    #[must_use]
     pub fn or_at_pos(mut self, p: Pos) -> Error {
         if let Some(mypos) = self.pos_mut() {
             if *mypos == Pos::None {
